@@ -193,7 +193,7 @@ class AwsAPI(BaseObject):
             file_ext=file_ext,
             version=version)
 
-    def create_bucket(self,
+    def create_folder(self,
                       bucket_name: str,
                       folder_name: str) -> None:
         """ Create a folder within an S3 Bucket
