@@ -5,3 +5,5 @@ from .download_from_s3 import DownloadFromS3
 from .find_latest_version_number import FindLatestVersionNumber
 from .find_file_by_version import FindFileByVersion
 from .read_from_cache import ReadFromCache
+from .create_bucket_folder import CreateBucketFolder
+from .upload_image_files import UploadImageFiles
